import 'package:flutter/material.dart';
import 'package:xinlake_platform/xinlake_platform.dart';

class PickFilesDemo extends StatefulWidget {
  const PickFilesDemo({Key? key}) : super(key: key);

  @override
  State<PickFilesDemo> createState() => _PickFilesState();
}

class _PickFilesState extends State<PickFilesDemo> {
  bool _isMultiSelection = false;
  String _mimeType = "*/*";
  String _openPath = "";
  String _defaultPath = "";
  String _filterName = "All files";
  String _filterPattern = "*.*";

  List<String>? _pathList;

  Widget _buildResults() {
    final style = Theme.of(context).textTheme.caption;
    // empty view
    if (_pathList == null) {
      return Padding(
        padding: const EdgeInsets.all(10),
        child: Text(
          "NULL",
          textScaleFactor: 2,
          style: style,
        ),
      );
    } else if (_pathList!.isEmpty) {
      return Padding(
        padding: const EdgeInsets.all(10),
        child: Text(
          "EMPTY",
          textScaleFactor: 2,
          style: style,
        ),
      );
    }

    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Padding(
          padding: const EdgeInsets.symmetric(vertical: 10),
          child: Text(
            "${_pathList!.length} ${_pathList!.length > 1 ? "files" : "file"} selected",
            style: style,
          ),
        ),
        ..._pathList!.map<Text>((path) {
          return Text(
            path,
            maxLines: 3,
            overflow: TextOverflow.ellipsis,
          );
        }).toList(),
      ],
    );
  }

  @override
  Widget build(BuildContext context) {
    return SingleChildScrollView(
      padding: const EdgeInsets.all(10),
      child: Column(
        children: [
          Row(
            children: [
              Expanded(
                child: TextFormField(
                  decoration: const InputDecoration(labelText: "Open path"),
                  initialValue: _openPath,
                  onChanged: (value) => _openPath = value,
                ),
              ),
              const SizedBox(width: 10),
              Expanded(
                child: TextFormField(
                  decoration: const InputDecoration(labelText: "Default path"),
                  initialValue: _defaultPath,
                  onChanged: (value) => _defaultPath = value,
                ),
              ),
            ],
          ),
          Row(
            children: [
              Expanded(
                child: TextFormField(
                  decoration: const InputDecoration(labelText: "Filter name"),
                  initialValue: _filterName,
                  onChanged: (value) => _filterName = value,
                ),
              ),
              const SizedBox(width: 10),
              Expanded(
                child: TextFormField(
                  decoration: const InputDecoration(labelText: "Filter pattern"),
                  initialValue: _filterPattern,
                  onChanged: (value) => _filterPattern = value,
                ),
              ),
            ],
          ),
          Row(
            children: [
              Expanded(
                child: TextFormField(
                  decoration: const InputDecoration(labelText: "Mime type"),
                  initialValue: _mimeType,
                  onChanged: (value) => _mimeType = value,
                ),
              ),
            ],
          ),
          Row(
            children: [
              const Expanded(
                child: Text("Multi selection"),
              ),
              Expanded(
                child: Container(
                  alignment: Alignment.centerLeft,
                  padding: const EdgeInsets.symmetric(vertical: 5),
                  child: Switch(
                    value: _isMultiSelection,
                    onChanged: (value) => setState(() => _isMultiSelection = value),
                  ),
                ),
              ),
            ],
          ),
          Row(
            children: [
              Expanded(
                child: ElevatedButton(
                  child: const Text("pickFiles"),
                  onPressed: () async {
                    var pathList = await XinlakePlatform.pickFiles(
                      isMultiSelection: _isMultiSelection,
                      openPath: _openPath,
                      mimeType: _mimeType,
                      defaultPath: _defaultPath,
                      filterName: _filterName,
                      filterPattern: _filterPattern,
                    );
                    setState(() => _pathList = pathList);
                  },
                ),
              ),
            ],
          ),
          _buildResults(),
        ],
      ),
    );
  }
}
